﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Stormtrooper
{
    internal class DrawningObjectStorm : IDrawningObject
    {
        private Drawning _storm = null;
        public DrawningObjectStorm(Drawning storm)
        {
            _storm = storm;
        }
        public float Step => _storm?.Storm?.Step ?? 0;
        public Drawning GetStormtrooper => _storm;
        public (float Left, float Right, float Top, float Bottom) GetCurrentPosition()
        {
            return _storm?.GetCurrentPosition() ?? default;
        }
        public void MoveObject(Direction direction)
        {
            _storm?.MoveTransport(direction);
        }
        public void SetObject(int x, int y, int width, int height)
        {
            _storm.SetPosition(x, y, width, height);
        }
        void IDrawningObject.DrawningObject(Graphics g)
        {
            if (_storm is DrawningMilitary)
                ((DrawningMilitary)_storm).DrawTransport(g);
            _storm.DrawTransport(g);
        }
        public string GetInfo() => _storm?.GetDataForSave();
        public static IDrawningObject Create(string data) => new DrawningObjectStorm(data.CreateDrawningStormtrooper());

        public bool Equals(IDrawningObject? other)
        {
            if (other == null)
            {
                return false;
            }
            var otherStormtrooper = other as DrawningObjectStorm;
            if (otherStormtrooper == null)
            {
                return false;
            }
            var stormtrooper = _storm.Storm;
            var otherStormtrooperStormtrooper = otherStormtrooper._storm.Storm;
            if (stormtrooper.Speed != otherStormtrooperStormtrooper.Speed)
            {
                return false;
            }
            if (stormtrooper.Weight != otherStormtrooperStormtrooper.Weight)
            {
                return false;
            }
            if (stormtrooper.BodyColor != otherStormtrooperStormtrooper.BodyColor)
            {
                return false;
            }
            if (stormtrooper is EntityMilitaryStormtrooper militaryStorm && otherStormtrooperStormtrooper is EntityMilitaryStormtrooper othermilitaryStorm)
            {
                if (militaryStorm.DopColor != othermilitaryStorm.DopColor)
                {
                    return false;
                }
                if (militaryStorm.BodyKit != othermilitaryStorm.BodyKit)
                {
                    return false;
                }
                if (militaryStorm.Rocket != othermilitaryStorm.Rocket)
                {
                    return false;
                }
                if (militaryStorm.SportLine != othermilitaryStorm.SportLine)
                {
                    return false;
                }
            }
            else if (stormtrooper is EntityMilitaryStormtrooper || otherStormtrooperStormtrooper is EntityMilitaryStormtrooper) return false;
            return true;
        }
    }
}
